@@ -212,8 +212,7 @@ class Error(StandardError):
     pass
 
 
-class TimeoutError(Error):
-    pass
+TimeoutError = socket.timeout
 
 
 class InterfaceError(Error):
@@ -771,7 +770,7 @@ class _StateContext(object):
 
 
 class _TdsSocket(object):
-    def __init__(self, login):
+    def __init__(self, login, sock):
         self._is_connected = False
         self._bufsize = login.blocksize
         self.login = None
@@ -790,7 +789,7 @@ class _TdsSocket(object):
 
         # Jeff's hack, init to no timeout
         self.query_timeout = login.connect_timeout if login.connect_timeout else login.query_timeout
-        self._sock = None
+        self._sock = sock
         import socket
         if hasattr(socket, 'socketpair'):
             tds_conn(self).s_signal, tds_conn(self).s_signaled = socket.socketpair(socket.AF_UNIX, socket.SOCK_DGRAM)
@@ -799,46 +798,20 @@ class _TdsSocket(object):
         if IS_TDS7_PLUS(self):
             # TDS 7/8 only supports little endian
             self.emul_little_endian = True
-        if IS_TDS7_PLUS(self) and login.instance_name and not login.port:
-            instances = tds7_get_instances(login.server_name)
-            if login.instance_name not in instances:
-                raise LoginError("Instance {0} not found on server {1}".format(login.instance_name, login.server_name))
-            instdict = instances[login.instance_name]
-            if 'tcp' not in instdict:
-                raise LoginError("Instance {0} doen't have tcp connections enabled".format(login.instance_name))
-            login.port = int(instdict['tcp'])
-        connect_timeout = login.connect_timeout
-
-        if not login.port:
-            login.port = 1433
-        for host in login.load_balancer.choose():
-            try:
-                tds_open_socket(self, host, login.port, connect_timeout)
-            except socket.error as e:
-                e = LoginError("Cannot connect to server '{0}': {1}".format(host, e), e)
-                continue
-            try:
-                from login import tds_login
-                tds_login(self._main_session, login)
-                text_size = login.text_size
-                if self.mars_enabled:
-                    self._setup_smp()
-                self._is_connected = True
-                q = []
-                if text_size:
-                    q.append('set textsize {0}'.format(int(text_size)))
-                if login.database and self.env.database != login.database:
-                    q.append('use ' + tds_quote_id(self, login.database))
-                if q:
-                    tds_submit_query(tds._main_session, ''.join(q))
-                    tds_process_simple_query(tds._main_session)
-            except Exception as e:
-                self._sock.close()
-                #raise
-                continue
-            break
-        else:
-            raise e
+        from login import tds_login
+        tds_login(self._main_session, login)
+        text_size = login.text_size
+        if self.mars_enabled:
+            self._setup_smp()
+        self._is_connected = True
+        q = []
+        if text_size:
+            q.append('set textsize {0}'.format(int(text_size)))
+        if login.database and self.env.database != login.database:
+            q.append('use ' + tds_quote_id(self, login.database))
+        if q:
+            tds_submit_query(tds._main_session, ''.join(q))
+            tds_process_simple_query(tds._main_session)
 
     def _setup_smp(self):
         from smp import SmpManager
@@ -858,19 +831,10 @@ class _TdsSocket(object):
 
     def read(self, size):
         try:
-            events = tds_select(self, TDSSELREAD, self.query_timeout)
-            if events & TDSPOLLURG:
-                buf = tds_conn(self).s_signaled.read(size)
-                if not self.in_cancel:
-                    tds_put_cancel(self)
-                return buf
-            elif events:
-                buf = self._sock.recv(size)
-                if len(buf) == 0:
-                    raise Error('Server closed connection')
-                return buf
-            else:
-                raise TimeoutError('Timeout')
+            buf = self._sock.recv(size)
+            if len(buf) == 0:
+                raise Error('Server closed connection')
+            return buf
         except TimeoutError:
             raise
         except:
@@ -884,9 +848,6 @@ class _TdsSocket(object):
         try:
             pos = 0
             while pos < len(data):
-                res = tds_select(self, TDSSELWRITE, self.query_timeout)
-                if not res:
-                    raise TimeoutError('Timeout')
                 flags = 0
                 if hasattr(socket, 'MSG_NOSIGNAL'):
                     flags |= socket.MSG_NOSIGNAL
